@@ -25,8 +25,9 @@ import tempfile
 from datetime import datetime
 import quip.field_builder as fb
 from argparse import RawTextHelpFormatter
+from colorama import Fore, Style, init
 
-version = "1.3.1"
+version = "1.4.2"
 UPDATE_ACTION = ["update", "u", "up"]
 FIELD_ACTION = ["fields", "f", "fi"]
 ICON_ACTION = ["icon", "resize-icon", "ri", "resize"]
@@ -36,9 +37,21 @@ BOOTSTRAP_ACTION = ["bootstrap", "bs", "boot", "bst", "baseline"]
 DOWNLOAD_ACTION = ["download", "pull"]
 UPLOAD_ACTION = ["upload", "push"]
 BUILD_ACTION = ["build", "b", "dist", "zip"]
+init()
+
+def cprint(text, color, end='\n'):
+    if len(str(text).strip()) == 0: return
+    fore = getattr(Fore, color.upper())
+    print('{0}{1}{2}'.format(fore, text, Style.RESET_ALL), end=end)
+
+def color(text, color, style='Normal'):
+    fore = getattr(Fore, color.upper())
+    style = getattr(Style, style.upper())
+    return '{0}{1}{2}{3}'.format(fore, style, text, Style.RESET_ALL)
 
 class Quip:
     def __init__(self, log_level=logging.INFO) -> None:
+        cprint(f"======= QUIP (v.{version}) =======", color="cyan")
         logging.basicConfig(level=log_level)
         self.in_project_folder = False
         self.args = self.parse_arguments()
@@ -49,6 +62,10 @@ class Quip:
     def parse_arguments(self):
         parser = argparse.ArgumentParser(description='Wrapper for UIP command.', formatter_class=RawTextHelpFormatter)
         subparsers = parser.add_subparsers(dest='action')
+        parser.add_argument('--config', '-c', default=None,
+                             help='path of the global config. Default is ~/.uip_config.yml')
+        parser.add_argument('--debug', '-v', action='store_true',
+                            help='show debug logs')
 
         parser_new = subparsers.add_parser('new', help='Creates new integration')
         parser_new.add_argument('name', help='name of the project')
@@ -107,14 +124,19 @@ class Quip:
         parser_icon.add_argument('--generate', '-g', action='store_true',
                              help='generate new icon')
 
-        parser.add_argument('--config', '-c', default=None,
-                             help='path of the global config. Default is ~/.uip_config.yml')
-        parser.add_argument('--debug', '-v', action='store_true',
-                            help='show debug logs')
+        parser_icon = subparsers.add_parser('config', help='show the configuration')
 
         args = parser.parse_args()
         print(args)
+
+        if args.action is None:
+            parser.print_help()
+            sys.exit(0)
         
+        if args.action in ["config"]:
+            # give a fake name because name is mandatory
+            args.name = ""
+
         if args.name is None:
             current_folder = os.getcwd()
             template_path = os.path.join(current_folder, "src", "templates", "template.json")
@@ -135,7 +157,7 @@ class Quip:
             else:
                 self.new_project()
                 self.dump_fields(write=True)
-            self.create_icon()
+            self.create_icon_safe()
         elif action in ICON_ACTION:
             if self.args.generate:
                 self.create_icon()
@@ -159,7 +181,7 @@ class Quip:
             else:
                 self.bootstrap_project()
             self.dump_fields(write=True)
-            self.create_icon()
+            self.create_icon_safe()
         elif action in UPLOAD_ACTION:
             if not self.args.template:
                 logging.error("This action only possible with --template option. For extensions use 'uip push' command.")
@@ -181,6 +203,10 @@ class Quip:
                 logging.error("This action only possible with --template option. For extensions use 'uip build' command.")
                 sys.exit(1)
             self.build_zip(self.project_name)
+        elif action == "config":
+            if not self.uip_global_config.get("new", False):
+                QuipGlobalConfig().check_config(self.uip_global_config)
+            sys.exit(0)
 
     def set_global_configs(self, project_name, config_path=None):
         if config_path is not None:
@@ -255,6 +281,14 @@ class Quip:
         elif len(converted) == 0:
             logging.info(f"Nothing to convert. Put an image file under templates folder and make sure the file name is not 'template_icon.png'")
 
+    def create_icon_safe(self, message=None):
+        try:
+            self.create_icon(message=message)
+        except Exception as ex:
+            logging.error(f"WARNING: Couldn't create a new ICON")
+            logging.error(f"Error: {ex}")
+            return
+
     def create_icon(self, message=None):
         try:
             from PIL import Image, ImageDraw, ImageFont
@@ -286,7 +320,8 @@ class Quip:
             correction_x = 3
             correction_y = -5
         
-        font = ImageFont.truetype("cour.ttf", size=font_size)
+        font_name = self._global_conf_defaults.get("icon_font", "cour.ttf")
+        font = ImageFont.truetype(font_name, size=font_size)
         img = Image.new('RGBA', (width, height), (255, 0, 0, 0))
         imgDraw = ImageDraw.Draw(img)
 
@@ -823,16 +858,19 @@ class Quip:
 class QuipGlobalConfig:
     def __init__(self, config_file=None) -> None:
         self.conf = {}
+        self.new_config = False
         if config_file is None:
             config_file = self.find_config_path()
         
         if config_file is not None:
             with open(config_file) as f:
                 self.conf = yaml.safe_load(f)
+            if self.new_config:
+                self.conf["new"] = True
 
     def find_config_path(self, config_path=None):
         home_folder = os.path.expanduser("~")
-        config_file = os.path.join(home_folder, ".uip_config.yml")
+        config_file = config_file_home = os.path.join(home_folder, ".uip_config.yml")
         if not os.path.exists(config_file):
             config_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", ".uip_config.yml")
         
@@ -840,8 +878,87 @@ class QuipGlobalConfig:
             logging.info(f"Using config from file : {config_file}")
             return config_file
         else:
-            logging.warn(f"Not using any config file.")
-            return None
+            logging.warn(f"Not using any config file. {config_file_home} or {config_file}")
+            config_file = self.setup_config(config_file_home)
+            self.new_config = True
+            return config_file
+    
+    def yes_or_no(self, question, default=None):
+        if default == True:
+            options = "(Y/n)"
+        elif default == False:
+            options = "(y/N)"
+        else:
+            options = "(y/n)"
+            default = None
+
+        while True:
+            answer = input(question + options + ": ").lower().strip()
+            
+            if len(answer) == 0 and default is not None:
+                return default
+            elif answer[0] in  ["y", "yes"]:
+                return True
+            elif answer[0] in  ["n", "no"]:
+                return False
+    
+    def setup_config(self, config_file):
+        logging.info("You don't have any config file. I think this is the first time you are running this tool.")
+        if self.yes_or_no(f"Do you want to download sample quip config? (Destination: {config_file}): ", default=True):
+            response = requests.get("https://stb-se-dev.s3.amazonaws.com/quip/.uip_config.yml.sample")
+            if response.ok:
+                conf = yaml.safe_load(response.text)
+                owner_name = input(f"Enter your name: ")
+                conf["extension.yml"]["owner"]["name"] = owner_name
+
+            with open(config_file, "w") as f:
+                yaml.dump(conf, f, sort_keys=False)
+            
+            logging.info(f"Config file created. Check {config_file}")
+            cprint("You need to pull the baseline projects. Use the following command.", color="cyan")
+            cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ue-baseline.git", color="cyan")
+            cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ut-baseline.git", color="cyan")
+            
+            self.check_config(conf)
+
+            return config_file
+        return None
+    
+    def check_config(self, conf):
+        print(yaml.dump(conf, sort_keys=False))
+        # check defaults
+        if "defaults" not in conf:
+            cprint("Defaults section is missing", color="red")
+        else:
+            if "template" not in conf["defaults"]:
+                cprint("Defaults>template tag is missing", color="red")
+            elif len(conf["defaults"]["template"]) == 0:
+                cprint("Defaults>template value is empty.", color="red")
+            
+            if "bootstrap" not in conf["defaults"]:
+                cprint("Defaults>bootstrap tag is missing", color="red")
+            else:
+                if "source" not in conf["defaults"]["bootstrap"]:
+                    cprint("Defaults>bootstrap>source tag is missing", color="red")
+                else:
+                    if not os.path.exists(conf["defaults"]["bootstrap"]["source"]):
+                        cprint("Defaults>bootstrap>source path is missing.", color="red")
+                        cprint("Be sure you use full path of the ue-baseline project. You can clone the project by using the following command.", color="red")
+                        cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ue-baseline.git\n", color="green")
+
+                if "template_source" not in conf["defaults"]["bootstrap"]:
+                    cprint("Defaults>bootstrap>template_source tag is missing", color="red")
+                else:
+                    if not os.path.exists(conf["defaults"]["bootstrap"]["template_source"]):
+                        cprint("Defaults>bootstrap>template_source path is missing.", color="red")
+                        cprint("Be sure you use full path of the ut-baseline project. You can clone the project by using the following command.", color="red")
+                        cprint("git clone https://gitlab.stonebranch.com/integration-prototypes/ut-baseline.git\n", color="green")
+
+
+
+            
+        
+
 
 class MyDumper(yaml.SafeDumper):
     # HACK: insert blank lines between top-level objects
@@ -855,7 +972,7 @@ class MyDumper(yaml.SafeDumper):
 def run():
     _quip = Quip(log_level=logging.INFO)
     _quip.main()
-    
+
 if __name__ == '__main__':
     _quip = Quip(log_level=logging.INFO)
     _quip.main()
